
# Slot: object




URI: [biolink:entity_to_outcome_association_mixin_object](https://w3id.org/biolink/vocab/entity_to_outcome_association_mixin_object)


## Domain and Range

[EntityToOutcomeAssociationMixin](EntityToOutcomeAssociationMixin.md) &#8594;  <sub>1..1</sub> [Outcome](Outcome.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [EntityToOutcomeAssociationMixin](EntityToOutcomeAssociationMixin.md)
